Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(416)

Unified Diff: sdk/lib/core/resource.dart

Issue 1385933002: clearly mark resource as deprecated (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: addressing comments Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « CHANGELOG.md ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/core/resource.dart
diff --git a/sdk/lib/core/resource.dart b/sdk/lib/core/resource.dart
index 17bdebcb1ec5e752336f7edc15ac8443b588aa86..e8c9c67d96fa866ee9cb50907bd0e1a2232264f8 100644
--- a/sdk/lib/core/resource.dart
+++ b/sdk/lib/core/resource.dart
@@ -5,16 +5,18 @@
part of dart.core;
/**
* A resource that can be read into the program.
*
- * WARNING: This API is _experimental_,
- * and it may be changed or removed in future releases
+ * WARNING: This API is _deprecated_,
+ * and it will be removed in 1.14. Please use
+ * https://pub.dartlang.org/packages/resource instead.
*
* A resource is data that can be located using a URI and read into
* the program at runtime.
* The URI may use the `package` scheme to read resources provided
* along with package sources.
*/
+@Deprecated('1.14')
abstract class Resource {
/**
* Creates a resource object with the given [uri] as location.
@@ -5,16 +5,18 @@
part of dart.core;
/**
- * A resource that can be read into the program.
+ * DEPRECATED. A resource that can be read into the program.
*
« no previous file with comments | « CHANGELOG.md ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698